/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 * 
 * == BEGIN LICENSE ==
 * 
 * Licensed under the terms of any of the following licenses at your
 * choice:
 * 
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 * 
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 * 
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 * 
 * == END LICENSE ==
 */
package net.fckeditor;

import javax.servlet.http.HttpServletRequest;

/**
 * Interface to provide session or request based functionality to FCKeditor.Java. Currently, the
 * implemeted class has to implement the following:
 * <ul>
 * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
 * file.</li>
 * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
 * <li>{@link #getUserFilesPath(HttpServletRequest)}: It is used by
 * {@link ConnectorHandler#getUserFilesPath(HttpServletRequest)} to build an user based 'BaseDir'.</li>
 * </ul>
 * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
 * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification methods for different
 * kinds of user actions.<br />
 * <br />
 * <b>Warning for commiters: </b>You have to awake that every change of this interface could break
 * all classes which implemented this interface. Therefore you should change this interface for
 * milestone releases only!
 * 
 * @version $Id: SessionData.java 1753 2008-03-20 17:37:49Z th-schwarz $
 */
public interface SessionData {

	/**
	 * Authenticates/enables the current user for uploading file.<br>
	 * If the implementation doesn't bother you, just return <code>true</code>.
	 * 
	 * @param request
	 *            Servlet request from user
	 * @return <code>true</code> if user can upload to the server else <code>false</code>
	 */
	public boolean isEnabledForFileUpload(final HttpServletRequest request);

	/**
	 * Authenticates/enables the current user for browsing files.<br>
	 * If the implementation doesn't bother you, just return <code>true</code>.
	 * 
	 * @param request
	 *            Servlet request from user
	 * @return <code>true</code> if use can browse the server else <code>false</code>
	 */
	public boolean isEnabledForFileBrowsing(final HttpServletRequest request);

	/**
	 * Getter for the user dependent 'BaseDir'.<br>
	 * <b>Important:</b>
	 * <ul>
	 * <li> If the implementation returns <code>null</code>, {@link ConnectorHandler} will used
	 * the default one! That's useful, if the implementation doesn't bother you.</li>
	 * <li>The returned directory string has to start with '/', but has to end without '/'.</li>
	 * <li>The dir has to be within the context</li>
	 * </ul>
	 * 
	 * @param request
	 * @return <code>null</code> or the 'BaseDir' string for the current user.
	 */
	public String getUserFilesPath(final HttpServletRequest request);
}